@@ -499,12 +499,24 @@ def dispatch(host: CPanelEndpoint, args: List[str]) -> str:
 		elif cmd_is(cmd, "list postgres database"):
 			r = host.dump(lambda: uapi.Postgresql.list_databases())
 
-		elif cmd_is(cmd, "rename mysql database"):
+		elif cmd_is(cmd, "rename postgres database"):
 			r = host.check(lambda: uapi.Postgresql.rename_database(oldname = args[3], newname = args[4]))
 
-		elif cmd_is(cmd, "delete mysql database", "rm mysql database", "remove mysql database"):
+		elif cmd_is(cmd, "delete postgres database", "rm postgres database", "remove postgres database"):
 			r = host.check(lambda: uapi.Postgresql.delete_database(name = args[3]))
 
+		elif cmd_is(cmd, "set postgres privilege"):
+			r = host.check(lambda: uapi.Postgresql.grant_all_privileges(user = args[3], database = args[4]))
+
+		elif cmd_is(cmd, "delete postgres privilege", "rm postgres privilege", "remove postgres privilege"):
+			r = host.check(lambda: uapi.Postgresql.revoke_all_privileges(user = args[3], database = args[4]))
+
+		elif cmd_is(cmd, "sync postgres grant"):
+			r = host.check(lambda: uapi.Postgresql.update_privileges())
+
+		elif cmd_is(cmd, "get postgres restriction"):
+			r = host.dump(lambda: uapi.Postgresql.get_restrictions())
+
 		else:
 			die("unrecognized command, {}".format(cmd))
 
